@@ -37,9 +37,7 @@ class baseWebBrowserController:
         self.cbCreateSearchResultDictionaryByBeutifulSoup = baseWebBrowserController.createSearchResultDictionaryByBeutifulSoup
         self.cbCreateSearchResultDataFrameByWebDriver = baseWebBrowserController.createSearchResultDataFrameByWebDriver
         self.cbCreateSearchResultDataFrameByBeutifulSoup = baseWebBrowserController.createSearchResultDataFrameByBeutifulSoup
-        
-        pass
-    
+            
     @Logger.loggerDecorator('Get WebDriverPath')
     def getWebDriverPath(self, _webDriverPath:scrapingConfig.settingValueStruct.WebDriverPath):
         
@@ -119,9 +117,9 @@ class baseWebBrowserController:
         if self.config.ScrapingType == self.config.settingValueStruct.ScrapingType.selenium.value:
             self.wDriver.get(url)
         elif self.config.ScrapingType == self.config.settingValueStruct.ScrapingType.beutifulSoup.value:
-            response = requests.get(url)
+            response = requests.get(url)            
             self.bSoup = BeautifulSoup(response.content, 'lxml')
-
+            
     @Logger.loggerDecorator('Normal-Delay')
     def Delay(self):
 
@@ -168,7 +166,7 @@ class baseWebBrowserController:
         return element
 
     @Logger.loggerDecorator('Create SearchResultDataFrame')
-    def createSearchResultDataFrame(self, locater:str = By.CSS_SELECTOR) -> DataFrame:
+    def createSearchResultDataFrame(self, locater:str = By.CSS_SELECTOR, *args, **kwargs) -> DataFrame:
 
         """
         スクレイピング結果をDataFrameで返す
@@ -183,15 +181,15 @@ class baseWebBrowserController:
             # 待機
             element = self.WebDriverWait(locater)
             # スクレイピング
-            return self.cbCreateSearchResultDataFrameByWebDriver(self, element)
+            return self.cbCreateSearchResultDataFrameByWebDriver(element, *args, **kwargs)
         elif self.config.ScrapingType == self.config.settingValueStruct.ScrapingType.beutifulSoup.value:
             # 待機
             self.Delay()
             # スクレイピング
-            return self.cbCreateSearchResultDataFrameByBeutifulSoup(self, self.bSoup)
+            return self.cbCreateSearchResultDataFrameByBeutifulSoup(self.bSoup, *args, **kwargs)
 
     @Logger.loggerDecorator('Create SearchResultDataFrame By WebDriver')
-    def createSearchResultDataFrameByWebDriver(self, element) -> DataFrame:
+    def createSearchResultDataFrameByWebDriver(self, element, *args, **kwargs) -> DataFrame:
 
         """
         WebDriverを使用してスレイピング結果からDataFrameを生成する(デリゲート用関数)
@@ -210,7 +208,7 @@ class baseWebBrowserController:
         pass
 
     @Logger.loggerDecorator('Create SearchResultDataFrame By BeutifulSoup') 
-    def createSearchResultDataFrameByBeutifulSoup(self, soup:BeautifulSoup) -> DataFrame:
+    def createSearchResultDataFrameByBeutifulSoup(self, soup:BeautifulSoup, *args, **kwargs) -> DataFrame:
         
         """
         ByBeutifulSoupを使用してスレイピング結果からDataFrameを生成する(デリゲート用関数)
